# Importing Resources to Fact Sheets
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/importing-resources-to-fact-sheets#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/importing-resources-to-fact-sheets#prerequisites)
  * [Step 1: Prepare Data](https://help.sap.com/docs/leanix/ea/importing-resources-to-fact-sheets#step-1:-prepare-data)
  * [Step 2: Convert a CSV File into LDIF Format](https://help.sap.com/docs/leanix/ea/importing-resources-to-fact-sheets#step-2:-convert-a-csv-file-into-ldif-format)
  * [Step 3: Create an Inbound Data Processor](https://help.sap.com/docs/leanix/ea/importing-resources-to-fact-sheets#step-3:-create-an-inbound-data-processor)
  * [Step 4: Complete a Processor Run to Import Data](https://help.sap.com/docs/leanix/ea/importing-resources-to-fact-sheets#step-4:-complete-a-processor-run-to-import-data)
  * [Summary](https://help.sap.com/docs/leanix/ea/importing-resources-to-fact-sheets#summary)


Import links as resources to application fact sheets using the Integration API.
